@@ -292,6 +292,8 @@ class Cache(object):
     def get(self, label, normalized = False, structural = False, saved_as = None):
         assert not (normalized and structural), 'The added matrix can not be simultaneously normalized and scaled'
 #        assert not scaled or self.scale_used, 'Trying to add scaled data, while the cache it not allowed to get it'
+        if label is None:
+            return np.random.choice(list(self.memory_default.values()))
         if normalized:
             try:
                 return self.memory_normalized[label]
@@ -400,4 +402,4 @@ def upload_complex_token(label : str, params_values : OrderedDict, evaluator, te
         indexes_vect[tensor_idx] = tuple([grid[tensor_idx] for grid in grids])    
         
     label_completed = (label, tuple(params_values.values()))
-    tensor_cache.add(label_completed, grid_function(indexes_vect))
\ No newline at end of file
+    tensor_cache.add(label_completed, grid_function(indexes_vect))
